==> eiffelstudio-18.01.10.1424.tar: F_code/C37/se1828.c <==
/*
 * Code for class SEQUENCE [NATURAL_8]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "se1828.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SEQUENCE}.readable */
EIF_BOOLEAN F605_6192 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("readable", 604, Current, 0, 0, 6446);
	RTGC;
	RTHOOK(1);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5254[Dtype(Current)-457])(Current);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {SEQUENCE}.force */
void F605_6194 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("force", 604, Current, 0, 1, 6448);
	RTHOOK(1);
	F1084_9968(Current, arg1);
	RTHOOK(2);
	RTEE;
}

/* {SEQUENCE}.prune */
void F605_6197 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
{
	GTCX
	RTEX;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("prune", 604, Current, 0, 1, 6451);
	RTGC;
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R5255[dtype-481])(Current);
	RTHOOK(2);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5261[dtype-457])(Current, (EIF_REFERENCE) &arg1);
	RTHOOK(3);
	if ((EIF_BOOLEAN) !F461_6061(Current)) {
		RTHOOK(4);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5304[dtype-562])(Current);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {SEQUENCE}.prune_all */
void F605_6198 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
{
	GTCX
	RTEX;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("prune_all", 604, Current, 0, 1, 6452);
	RTGC;
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R5255[dtype-481])(Current);
	for (;;) {
		RTHOOK(2);
		if (F461_6061(Current)) break;
		RTHOOK(3);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5261[dtype-457])(Current, (EIF_REFERENCE) &arg1);
		RTHOOK(4);
		if ((EIF_BOOLEAN) !F461_6061(Current)) {
			RTHOOK(5);
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R5304[dtype-562])(Current);
		}
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

void EIF_Minit1828 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C37/se1828.c <==
/*
 * Code for class SEQUENCE [INTEGER_32]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "se1828.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SEQUENCE}.readable */
EIF_BOOLEAN F605_6192 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("readable", 604, Current, 0, 0, 6446);
	RTGC;
	RTHOOK(1);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5254[Dtype(Current)-457])(Current);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {SEQUENCE}.force */
void F605_6194 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("force", 604, Current, 0, 1, 6448);
	RTGC;
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Current)-562])(Current, (EIF_REFERENCE) &arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {SEQUENCE}.prune */
void F605_6197 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("prune", 604, Current, 0, 1, 6451);
	RTGC;
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R5255[dtype-481])(Current);
	RTHOOK(2);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5261[dtype-457])(Current, (EIF_REFERENCE) &arg1);
	RTHOOK(3);
	if ((EIF_BOOLEAN) !F461_6061(Current)) {
		RTHOOK(4);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5304[dtype-562])(Current);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {SEQUENCE}.prune_all */
void F605_6198 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("prune_all", 604, Current, 0, 1, 6452);
	RTGC;
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R5255[dtype-481])(Current);
	for (;;) {
		RTHOOK(2);
		if (F461_6061(Current)) break;
		RTHOOK(3);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5261[dtype-457])(Current, (EIF_REFERENCE) &arg1);
		RTHOOK(4);
		if ((EIF_BOOLEAN) !F461_6061(Current)) {
			RTHOOK(5);
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R5304[dtype-562])(Current);
		}
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

void EIF_Minit1828 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
